@@ -2,12 +2,12 @@ package Yars::Command::yars_generate_diskmap;
 
 # PODNAME: yars_generate_diskmap
 # ABSTRACT: generate a mapping from servers + hosts to buckets for yars.
-our $VERSION = '1.15'; # VERSION
+our $VERSION = '1.16'; # VERSION
 
 
 use strict;
 use warnings;
-use JSON::XS;
+use JSON::MaybeXS ();
 use Getopt::Long qw( GetOptions );
 use Pod::Usage qw( pod2usage );
 use feature 'say';
@@ -80,7 +80,7 @@ sub dense {
         ]};
     }
 
-    my $out = JSON::XS->new->space_after->encode({ servers => \@conf });
+    my $out = JSON::MaybeXS->new->space_after->encode({ servers => \@conf });
     $out =~ s/{/\n{/g;
     $out =~ s/\[/\n[/g;
     $out =~ s/\],/],\n/g;
