@@ -1,7 +1,7 @@
 package Yars::Routes;
 
 # ABSTRACT: set up the routes for Yars.
-our $VERSION = '1.15'; # VERSION
+our $VERSION = '1.16'; # VERSION
 
 
 use strict;
@@ -17,7 +17,7 @@ use List::Util qw/shuffle/;
 use List::MoreUtils qw/uniq/;
 use Digest::file qw/digest_file_hex/;
 use File::Basename qw/basename/;
-use Mojo::JSON qw( encode_json );
+use JSON::MaybeXS qw( encode_json );
 use Yars::Util qw( format_tx_error );
 
 BEGIN {
@@ -662,7 +662,7 @@ Yars::Routes - set up the routes for Yars.
 
 =head1 VERSION
 
-version 1.15
+version 1.16
 
 =head1 SYNOPSIS
 
